==> OpenMesh-3.0.tar.gz: OpenMesh-3.0/Documentation/a00006.js <==
var a00006 =
[
    [ "Features and Goals of OpenMesh", "a00012.html", null ],
    [ "The Halfedge Data Structure", "a00016.html", null ],
    [ "Mesh Iterators and Circulators", "a00026.html", [
      [ "Iterators", "a00026.html#it_iters", [
        [ "Deleted Elements", "a00026.html#deletedElements", null ]
      ] ],
      [ "How to use iterators in OpenMesh", "a00026.html#it_iters_h", null ],
      [ "Skipping Iterators", "a00026.html#it_iters_skipping", null ],
      [ "Circulators", "a00026.html#it_circs", null ],
      [ "How to use circulators in OpenMesh", "a00026.html#it_circs_h", null ]
    ] ],
    [ "How to navigate on a mesh", "a00032.html", [
      [ "Overview", "a00032.html#nav_overview", null ],
      [ "Introduction", "a00032.html#nav_intro", null ],
      [ "Navigating over halfedges", "a00032.html#nav_he", null ],
      [ "Mesh boundaries", "a00032.html#nav_bound", null ],
      [ "Using incoming and outgoing halfedges", "a00032.html#nav_io", null ],
      [ "Using opposite halfedges", "a00032.html#nav_opposite", null ]
    ] ],
    [ "Read and write meshes from files", "a00024.html", [
      [ "Step 1 - IOManager quick start", "a00024.html#mesh_io_quick", null ],
      [ "Step 2 - The theory behind IOManager", "a00024.html#mesh_io_theory", null ],
      [ "Step 3 - How to extend IOManager", "a00024.html#mesh_io_extend", [
        [ "Adding support for a new file format", "a00024.html#mesh_io_extend_fileformat", null ],
        [ "Adding support for a new data structure", "a00024.html#mesh_io_extend_datastruct", null ]
      ] ]
    ] ],
    [ "Some basic operations: Flipping and collapsing edges", "a00034.html", [
      [ "Flipping edges in triangle meshes", "a00034.html#op_flip", null ],
      [ "Collapsing edges", "a00034.html#op_collapse", null ]
    ] ],
    [ "Conceptual Class Hierarchy", "a00018.html", [
      [ "Building the kernel", "a00018.html#ch_kernel", null ],
      [ "Building the mesh", "a00018.html#ch_complete", null ]
    ] ],
    [ "Specifying your MyMesh", "a00020.html", [
      [ "Polygonal or Triangle Mesh?", "a00020.html#sec_select_face_type", null ],
      [ "Choosing the right kernel", "a00020.html#sec_select_kernel", null ],
      [ "Mesh Traits", "a00020.html#sec_select_traits", [
        [ "Changing the Point type", "a00020.html#sec_change_point", null ],
        [ "Adding Predefined Attributes", "a00020.html#sec_add_attributes", null ],
        [ "Adding User-Defined Elements", "a00020.html#sec_add_traits", null ],
        [ "Using traits defined by algorithms", "a00020.html#sec_algo_traits", null ]
      ] ],
      [ "Dynamic Properties", "a00020.html#sec_properties", null ],
      [ "Final Implementation Example", "a00020.html#sec_traits_example", null ]
    ] ]
];

==> OpenMesh-6.2.tar.gz: OpenMesh-6.2/Documentation/a00006.js <==
var a00006 =
[
    [ "Features and Goals of OpenMesh", "a00012.html", null ],
    [ "The Halfedge Data Structure", "a00016.html", null ],
    [ "Mesh Iterators and Circulators", "a00026.html", [
      [ "Iterators", "a00026.html#it_iters", [
        [ "Deleted Elements", "a00026.html#deletedElements", null ]
      ] ],
      [ "How to use iterators in OpenMesh", "a00026.html#it_iters_h", null ],
      [ "Skipping Iterators", "a00026.html#it_iters_skipping", null ],
      [ "Circulators", "a00026.html#it_circs", null ],
      [ "How to use circulators in OpenMesh", "a00026.html#it_circs_h", null ]
    ] ],
    [ "How to navigate on a mesh", "a00032.html", [
      [ "Overview", "a00032.html#nav_overview", null ],
      [ "Introduction", "a00032.html#nav_intro", null ],
      [ "Navigating over halfedges", "a00032.html#nav_he", null ],
      [ "Mesh boundaries", "a00032.html#nav_bound", null ],
      [ "Using incoming and outgoing halfedges", "a00032.html#nav_io", null ],
      [ "Using opposite halfedges", "a00032.html#nav_opposite", null ],
      [ "Getting the to and from vertices", "a00032.html#nav_to_from", null ]
    ] ],
    [ "Read and write meshes from files", "a00024.html", [
      [ "Step 1 - IOManager quick start", "a00024.html#mesh_io_quick", null ],
      [ "Step 2 - The theory behind IOManager", "a00024.html#mesh_io_theory", null ],
      [ "Step 3 - How to extend IOManager", "a00024.html#mesh_io_extend", [
        [ "Adding support for a new file format", "a00024.html#mesh_io_extend_fileformat", null ],
        [ "Adding support for a new data structure", "a00024.html#mesh_io_extend_datastruct", null ]
      ] ]
    ] ],
    [ "Some basic operations: Flipping and collapsing edges", "a00034.html", [
      [ "Flipping edges in triangle meshes", "a00034.html#op_flip", null ],
      [ "Collapsing edges", "a00034.html#op_collapse", null ]
    ] ],
    [ "Conceptual Class Hierarchy", "a00018.html", [
      [ "Building the kernel", "a00018.html#ch_kernel", null ],
      [ "Building the mesh", "a00018.html#ch_complete", null ]
    ] ],
    [ "Specifying your MyMesh", "a00020.html", [
      [ "Polygonal or Triangle Mesh?", "a00020.html#sec_select_face_type", null ],
      [ "Choosing the right kernel", "a00020.html#sec_select_kernel", null ],
      [ "Mesh Traits", "a00020.html#sec_select_traits", [
        [ "Changing the Point type", "a00020.html#sec_change_point", null ],
        [ "Adding Predefined Attributes", "a00020.html#sec_add_attributes", null ],
        [ "Adding User-Defined Elements", "a00020.html#sec_add_traits", null ],
        [ "Using traits defined by algorithms", "a00020.html#sec_algo_traits", null ]
      ] ],
      [ "Dynamic Properties", "a00020.html#sec_properties", null ],
      [ "Final Implementation Example", "a00020.html#sec_traits_example", null ]
    ] ]
];
